@@ -32,12 +32,12 @@ class TextField(Element):
             when the field is not filled at form submission.
         placeholder: the text message shown when the field is not filled.
     """
-    def __init__(self, title, name=None, required_message=None, value=None, placeholder=None, on_change=None, id=None):
+    def __init__(self, title, name=None, required_message=None, password=False, value=None, placeholder=None, on_change=None, id=None):
         on_change_uuid = callbackRegistry.uuid_for_callback(on_change)
         if name is None:
             name = title.lower()
         super().__init__('TextField', title=title, name=name, required_message=required_message,
-                            value=value, placeholder=placeholder, on_change=on_change_uuid, id=id)
+                            value=value, placeholder=placeholder, style={'password': password}, on_change=on_change_uuid, id=id)
 
 class TextArea(Element):
     """Create a text area object
@@ -180,9 +180,9 @@ class Button(Element):
         icon: the icon in front of the button title. For string values see https://ant.design/components/icon/
         on_click: a custom function will be called when the button is clicked 
     """
-    def __init__(self, title="Go", style=None, icon=None, on_click=None, id=None):
+    def __init__(self, title="Go", style=None, icon=None, on_click=None, link_to=None, id=None):
         on_click_uuid = callbackRegistry.uuid_for_callback(on_click)
-        super().__init__('Button', title=title, style=style, icon=icon, on_click=on_click_uuid, id=id)
+        super().__init__('Button', title=title, style=style, icon=icon, link_to=link_to, on_click=on_click_uuid, id=id)
 
 class Link(Element):
     """Create a hyperlink on the page
